DROP TABLE IF EXISTS projets CASCADE;
DROP TABLE IF EXISTS user CASCADE;
DROP TABLE IF EXISTS entrepreneur CASCADE;
DROP TABLE IF EXISTS administrator CASCADE;
DROP TABLE IF EXISTS sectionCell CASCADE;
DROP TABLE IF EXISTS rendez_vous CASCADE;
DROP TABLE IF EXISTS comptes_rendus CASCADE;
DROP TABLE IF EXISTS concerner CASCADE;
DROP TABLE IF EXISTS formes CASCADE;

CREATE TABLE projets
(
    id_projet     SERIAL NOT NULL,
    nom_projet    VARCHAR(255),
    logo          BYTEA,
    date_creation DATE,
    status_projet VARCHAR(255),
    CONSTRAINT pk_projet PRIMARY KEY (id_projet)
);

CREATE TABLE user
(
id_utilisateur      SERIAL    NOT NULL,
nom_utilisateur     VARCHAR(255)      ,
prenom_utilisateur  VARCHAR(255)      ,
mail_principal      VARCHAR(255)      ,
mail_secondaire     VARCHAR(255)      ,
numero_telephone    VARCHAR(20)       ,
CONSTRAINT pk_utilisateur PRIMARY KEY (id_utilisateur) );

CREATE TABLE entrepreneur
(
    id_entrepreneur SERIAL REFERENCES user (id_utilisateur),
    ecole           VARCHAR(255),
    filiere         VARCHAR(255),
    status_snee     BOOLEAN,
    CONSTRAINT pk_entrepreneur PRIMARY KEY (id_entrepreneur)
);

CREATE TABLE administrator
(
    id_administrateur SERIAL REFERENCES user (id_utilisateur),
    CONSTRAINT pk_administrateur PRIMARY KEY (id_administrateur)
);

CREATE TABLE sectionCell
(
    id_section        SERIAL NOT NULL,
    titre             VARCHAR(255),
    contenu_section   TEXT,
    date_modification TIMESTAMP,
    CONSTRAINT pk_section PRIMARY KEY (id_section)
);

CREATE TABLE rendez_vous
(
    id_rdv    SERIAL NOT NULL,
    date_rdv  DATE,
    heure_rdv TIME,
    duree_rdv TIME,
    lieu_rdv  VARCHAR(255),
    sujet_rdv TEXT,
    CONSTRAINT pk_rdv PRIMARY KEY (id_rdv)
);

CREATE TABLE comptes_rendus
(
    id_compte_rendu      SERIAL NOT NULL,
    contenu_compte_rendu TEXT,
    CONSTRAINT pk_compte_rendu PRIMARY KEY (id_compte_rendu)
);

CREATE TABLE concerner
(
    id_section SERIAL REFERENCES sectionCell (id_section),
    id_rdv     SERIAL REFERENCES sectionCell (id_rdv),
    CONSTRAINT pk_concerner PRIMARY KEY (id_section, id_rdv)
);


ALTER TABLE projets
    ADD CONSTRAINT fk1_projet FOREIGN KEY (id_administrateur)
        REFERENCES administrator (id_administrateur)
        ON DELETE CASCADE;

ALTER TABLE projets
    ADD CONSTRAINT fk2_projet FOREIGN KEY (id_entrepreneur_participation)
        REFERENCES entrepreneur (id_entrepreneur)
        ON DELETE CASCADE;

ALTER TABLE entrepreneur
    ADD CONSTRAINT fk1_entrepreneur FOREIGN KEY (id_projet_propose)
        REFERENCES projets (id_projet)
        ON DELETE CASCADE;

ALTER TABLE sectionCell
    ADD CONSTRAINT fk1_section FOREIGN KEY (id_projet)
        REFERENCES projets (id_projet)
        ON DELETE CASCADE;

ALTER TABLE sectionCell
    ADD CONSTRAINT fk2_section FOREIGN KEY (id_administrateur)
        REFERENCES administrator (id_administrateur)
        ON DELETE CASCADE;

ALTER TABLE rendez-vous
    ADD CONSTRAINT fk1_rdv FOREIGN KEY (id_entrepreneur)
    REFERENCES entrepreneur (id_entrepreneur)
    ON
DELETE
CASCADE;

ALTER TABLE rendez-vous
    ADD CONSTRAINT fk2_rdv FOREIGN KEY (id_administrateur)
    REFERENCES administrator (id_administrateur)
    ON
DELETE
CASCADE;

ALTER TABLE comptes-rendus
    ADD CONSTRAINT fk1_compte_rendu FOREIGN KEY (id_rdv)
    REFERENCES rendez_vous (id_rdv)
    ON
DELETE
CASCADE;









